//***************** (c) 2010 BTC Korporacja ***********************************
//                     http://www.kamami.com
// PROJECT  : KAmodBTM222 Example
// BOARD    : ZL15AVR (with ATmega32 in socket U1)
// COMPILER : WinAVR
//
//******************************************************************************
//
//-----------------------------------------------------------------------------
//    KAmodBTM222 software library
//-----------------------------------------------------------------------------
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
//  This sample works with ZL15AVR evaluation board.
//
//  This program performs simple configuration of module (sets module's name), 
//  reads PIN and displays it. Then 'KAmodBTM222 demo' string is sent every second
//  via Bluetooth.
//
//  After running this program connect module to your PC, run terminal program,
//  for example HyperTerminal, configure it to connect to proper COM port, you
//  should see 'KAmodBTM222 demo' appearing every second on your screen.
//
//
//  Module stores its configuration, so you need to do it only once.
//  In real application rather use computer with terminal application for 
//  module's configureation than do it with microcontroller application.
//  Samlpe program shows, that it can be done this way, but only to make demo
//  easy to run.
//
//-----------------------------------------------------------------------------  
//  Connections:
//  GND and VCC of KAmodBTM222 should be connected to power supply, 3.3V and 5V
//  voltages can be used, but set JP2 jumper in proper position BEFORE connecting 
//  it!
//
//  KAmodBTM222  |   ZL15AVR
//  --------------------------
//  PD1 (Con18)  |   RXI (JP1)
//  PD0 (Con18)  |   TXO (JP1)
//  PB2 (Con16)  |   nRES (JP1)
//
//
//  LCD display connections
//  
//  D4 (LCD_CHAR/con13) - PA4 (con15)
//  D5 (LCD_CHAR/con13) - PA5 (con15)
//  D6 (LCD_CHAR/con13) - PA6 (con15)
//  D7 (LCD_CHAR/con13) - PA7 (con15)
//  E  (LCD_CHAR/con13) - PA2 (con15)
//  RS (LCD_CHAR/con13) - PA3 (con15)
//  RW (LCD_CHAR/con13) - GND (con15)
//
// 
//-----------------------------------------------------------------------------


#define F_CPU 16000000UL
#include "KAmodBTM222.h"
#include "HD44780.h"
#include <util/delay.h>	




int main(void)
{
	char Pin[5], Buffer[16];
	LCD_Initialize();
	LCD_GoTo(0,0);
	LCD_WriteText("**** KAmodBT ***");
	LCD_GoTo(0,1);
	LCD_WriteText("Wait for BTM222 ");

	_delay_ms(3000);

	LCD_GoTo(0,1);
	LCD_WriteText(" Initialization ");


	// Initialize communication
	if (KAmodBT_Initialize()!=BT_OK)
	{
		LCD_GoTo(0,1);
		LCD_WriteText("  Init. error!  ");
		while(1);
	}


	
	// Enter BTM222's AT mode
	if (KAmodBT_EnterATMode()!=BT_OK)
	{
		LCD_GoTo(0,1);
		LCD_WriteText(" AT mode error! ");
	}
	
	LCD_GoTo(0,1);
	LCD_WriteText("  Setting name  ");


	// Set module's name (seen by host device)		
	if (KAmodBT_SetName("KAmodBTM222 demo")!=BT_OK)
	{
		LCD_GoTo(0,1);
		LCD_WriteText("Set name failed!");
	}	


	LCD_GoTo(0,0);
	LCD_WriteText("                ");
	LCD_GoTo(0,1);
	LCD_WriteText("                ");

	
	// Read module's PIN (default '1234') and display it
	KAmodBT_GetPin(Pin);
	sprintf(Buffer, "Pin: %s", Pin);
	LCD_GoTo(0,0);
	LCD_WriteText(Buffer);

	// Read module's name and display it to check if it was written correctly.
	KAmodBT_GetName(Buffer);
	LCD_GoTo(0,1);
	LCD_WriteText(Buffer);

		
	//Reset module
	KAmodBT_Reset();
	_delay_ms(3000);
		

	// Send some text once a second.
	while(1)
	{
		KAmodBT_SendBuffer("KAmodBTM222 demo\n\r");
		_delay_ms(1000);
	};
    	
}
